@@ -5,7 +5,7 @@
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfu.h,v 1.14 2005/06/05 22:00:10 cade Exp $
+ * $Id: vfu.h,v 1.18 2006/09/01 21:34:26 cade Exp $
  *
  */
 
@@ -146,8 +146,8 @@
       const char*   view();
       void          drop_view();
 
-      void          update_stat( const struct stat* a_new_stat,
-                                 int a_is_link );
+      void          update_stat( const struct stat* a_new_stat = NULL, int a_is_link = -1 );
+      
       const char*   type_str() { return (const char*)_type_str; }
       const char*   mode_str() { return (const char*)_mode_str; }
       const struct  stat* st() { return (const struct stat*)&_st; }
@@ -209,6 +209,9 @@
   extern VString         files_mask;
   extern VArray         files_mask_array;
 
+  /* misc */
+  extern int print_help_on_exit;
+
 /*############################################ GLOBAL STRUCTS  #########*/
 
   extern VArray dir_tree;
@@ -319,6 +322,7 @@ void vfu_user_external_exec( int a_key );
 void vfu_user_menu();
 
 void vfu_inc_search();
+void vfu_goto_filename( const char* fname );
 
 /*
   Main files op's
@@ -343,5 +347,4 @@ void vfu_clipboard( int act );
 
 void vfu_jump_to_mountpoint( int all );
 
-
 #endif//_VFU_H_
