@@ -20,7 +20,7 @@
  *
  */
 
-#define VFU_VERSION "4.09"
+#define VFU_VERSION "4.10"
 
 #define HEADER "VF/U v" VFU_VERSION " (" __DATE__ ") by (c) Vladi Belperchinov-Shabanski `Cade' 1996-2009"
 #define CONTACT "<cade@biscom.net> <cade@datamax.bg> [http://cade.datamax.bg]"
@@ -50,7 +50,7 @@
 #endif
 
 #ifndef FILENAME_CONF_GLOBAL2
-#define FILENAME_CONF_GLOBAL2 "/usr/local/" FILENAME_CONF
+#define FILENAME_CONF_GLOBAL2 "/usr/lib/vfu/" FILENAME_CONF
 #endif
 
 #define RX_TEMP_LIST "RX_TEMP_LIST"
