@@ -1,9 +1,11 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-1999
+ * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-2003
  *
  * SEE `README',LICENSE' OR COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
+ * $Id: clusters.h,v 1.5 2003/01/21 19:56:35 cade Exp $
+ *
  */
 /*
  *
@@ -21,6 +23,7 @@
 #include <string.h>
 #include <limits.h>
 #include <assert.h>
+
 #ifndef ASSERT
 #define ASSERT assert
 #endif
@@ -138,7 +141,6 @@ class DCluster : public BaseCluster
     void get( int pn, void* pe );
 
     const void* operator [] ( int pn ) { ASSERT( pn >= 0 && pn < cnt  ); return data + (pn*es); };
-
   };
 
 /****************************************************************************
@@ -154,7 +156,6 @@ class TDCluster : public DCluster
 
     const T* operator [] ( int pn ) const { ASSERT( pn >= 0 && pn < cnt  ); return (T*)(data + (pn*es)); };
     T operator [] ( int pn ) { ASSERT( pn >= 0 && pn < cnt  ); return (*((T*)(data + (pn*es)))); };
-
   };
 
 /****************************************************************************
@@ -293,8 +294,8 @@ class BSet
     
     void reverse() { for(int z = 0; z < datasize; z++) data[z] = ~data[z]; };
     void set( int pn, int val ) { if ( val ) set1( pn ); else set0( pn ); };
-    void set_all1() { if (data) memset( data, 0xff, datasize ); };
-    void set_all0() { if (data) memset( data, 0x00, datasize ); };
+    void set_all1() { if ( data ) memset( data, 0xff, datasize ); };
+    void set_all0() { if ( data ) memset( data, 0x00, datasize ); };
 
     const int operator [] ( int pn )
        { ASSERT( pn >= 0 && pn < size  ); return get( pn ); };
@@ -304,68 +305,10 @@ class BSet
     BSet& operator  = ( const BSet &b1 );
     BSet& operator &= ( const BSet &b1 );
     BSet& operator |= ( const BSet &b1 );
-    BSet  operator ~  ();
+    BSet  operator  ~ ();
 
     friend BSet operator & ( const BSet &b1, const BSet &b2 );
     friend BSet operator | ( const BSet &b1, const BSet &b2 );
-
   };
 
-/****************************************************************************
-**
-** V cluster (this is a versatile cluster that holds data as strings)
-**
-****************************************************************************/
-  
-  #ifndef SIZE_T_MAX
-  #define SIZE_T_MAX    INT_MAX
-  #endif
-
-  class PSZCluster : public PCluster
-    {
-    size_t max_str_len;
-    size_t min_str_len;
-
-    public:
-    PSZCluster() : PCluster() { max_str_len = 0; min_str_len = SIZE_T_MAX; };
-
-    size_t maxlen() { return max_str_len; };
-
-    int add( const char* pe );
-    int ins( int pn, const char* pe );
-    void put( int pn, const char* pe );
-    void get( int pn, char* pe );
-    char* get( int pn );
-
-    void sort( int ascending = 1 );
-    
-    void freeall() { max_str_len = min_str_len = 0; BaseCluster::freeall(); };
-
-    char* operator [] ( int pn ) { ASSERT( pn >= 0 && pn < cnt  ); return (char*)((void**)data)[pn]; };
-
-    protected:
-    void q_sort( int l, int h );
-    
-    virtual void destroy_element( void* pe )
-      { delete (char*)(((void**)pe)[0]); };
-
-    };
-
-////////////////////////////////////////////////////////////////////////////
-//
-//
-//
-
-////////////////////////////////////////////////////////////////////////////
-//
-// misc support functions
-//
-
-int SaveToFile( FILE *f, PSZCluster *szc );
-int SaveToFile( const char *fname, PSZCluster *szc );
-int LoadFromFile( FILE *f, PSZCluster *szc, size_t maxlen );
-int LoadFromFile( const char *fname, PSZCluster *szc, size_t maxlen );
-
-////////////////////////////////////////////////////////////////////////////
-
 #endif //_CLUSTERS_H_
