@@ -1,5 +1,5 @@
 /*
- *  $Header: /cvs/vslib/getopt2.h,v 1.2 2001/10/28 13:53:02 cade Exp $
+ *  $Header: /cvs/vslib/getopt2.h,v 1.3 2007/12/16 13:53:36 cade Exp $
  *
  *  Copyright (C) 1994 Arno Schaefer
  *
@@ -16,6 +16,9 @@
 #define GETOPT(opts) while((optc = getopt2(argc, argv, opts)) != -1)
 
 
+/* avoid C/C++ linkage declarations conflict with <getopt.h> */
+extern "C" {
+
 extern char *optarg;
 extern int optind;
 extern int opterr;
@@ -28,6 +31,8 @@ extern int optc;
  */
 extern int opterr_report;
 
+} /* extern "C" */
+
 /* name changed to getopt2 to avoid library function mismatch */
 
 int getopt2(int argc, char *argv[], char *optstring);
