@@ -4,7 +4,7 @@
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: test.cpp,v 1.17 2004/12/29 02:44:21 cade Exp $
+ * $Id: test.cpp,v 1.18 2008/01/18 18:40:46 cade Exp $
  *
  */
 
@@ -19,16 +19,16 @@ void test1()
   str_low( str ); // lower case
 
   VArray va = str_split( " +", str ); // array contains `dlroW' at pos 0 and `olleH' at 1
-  
+
   va.reverse(); // array reversed: `dlroW' at pos 1 and `olleH' at 0
-  
+
   int z;
   for( z = 0; z < va.count(); z++ )
     {
     str_reverse( va[z] ); // reverses each string element
     }
-  
-  
+
+
   str = str_join( va, " " ); // joins into temporary string
 
   printf( "************************ test 1 result is: %s\n", str.data() ); // this should print `hello world'
@@ -39,20 +39,20 @@ void test2()
   VArray va;
   va.push( "hello" ); // pos 0
   va.push( "world" ); // pos 1
-  
+
   va.ins( 1, "your" ); // pos 1 shifted
-  
+
   va[1] = "my"; // replaces `your'
   va[3] = "!";  // set outside the size, array is extended
-  
+
   VString str = va.pop(); // pops last element, str is now `!'
-  
+
   str = str_join( va, "-" ); // joins to given string
-  
+
   str_tr( str, "-", " " ); // replaces dashes with spaces
-  
+
   str_replace( str, " my ", " " ); // removes ` my '
-  
+
   printf( "************************ test 2 result is: %s\n", str.data() ); // this should print `hello world'
 }
 
@@ -60,7 +60,7 @@ void test3()
 {
   VTrie tr; // hash-like
   VArray va;
-  
+
   // inserting keys and values
   tr[ "tralala" ] = "data1";
   tr[ "opala"   ] = "data2";
@@ -105,6 +105,7 @@ void test3()
   if( re.m( "tralala85." ) ) // match against regexp
     printf( "sub 1 = %s\n", re[1].data() ); // re[1] returns `85'
 
+  VString vs;
   if( re.m( "tralala85.", "(la)+" ) ) // match against regexp
     {
     printf( "sub 0 = %s\n", re[0].data() ); // `lala'
@@ -112,10 +113,13 @@ void test3()
     }
 
   printf( "--------------------\n" );
-  v1 = str_split( " +", "tralala  opala and another   one" ); // splits on spaces
+  v1 = str_split( ",", "*.tralala,opala and another   one" ); // splits on spaces
   v1.print();
 
   printf( "joined: %s\n", (const char*)str_join( v1, "---" ) ); // join the same data back
+  VString m1 = v1[0];
+  VString m2 = v1[1];
+  printf( "1[%s] 2[%s]\n", m1.data(), m2.data() );
 
   printf( "--------------------\n" );
   v1 = str_split( " +", "tralala  opala and another   one", 3 ); // splits data on spaces up to 3 elements
@@ -145,9 +149,9 @@ void test3()
     printf("---\n");
     aa[i].print();
     }
-  
+
   printf( "---box test-----------------------------\n" );
-  i = 20000;
+  i = 20;
   while( i-- )
   {
   v1.push( "this" );
@@ -155,12 +159,23 @@ void test3()
   v1.push( "test" );
   v1.push( "simple" );
   }
-  
+
   v1.print();
   VArray vv = v1; // this makes vv data aliased to the data of v1
   vv.print(); // actually print the v1's data which is shared right now
   vv.set( 0, "---" ); // vv makes own copy of the array data
   vv.print(); // vv's data is no more aliased to v1's
+
+
+
+  VRegexp re_see( "^\\s*see\\s*=\\s*([^, \011]*)\\s*,(.*)$", "i" );
+  if( re_see.m( "see=*.tgz,tralala" ) )
+    {
+    VString str;
+    str = str + re_see[1] + re_see[2];
+    printf( "VRegexp[1+2]=[%s]\n", str.data() );
+    }
+
   printf( "************************ test 3 ends here\n" );
 }
 
@@ -170,7 +185,7 @@ void test4()
 
   int i;
   int ii;
-  
+
   VArray va;
   ii = 20;
   i = ii;
@@ -179,7 +194,7 @@ void test4()
     va = str_split( ",", "this is, just a simple. but fixed, nonsense test, voila :)" );
     printf( "%d%% va count = %d\n", (100*i)/ii, va.count() );
     }
-  
+
   VString set;
   VString cat;
   VString setn;
@@ -188,14 +203,14 @@ void test4()
   VString setp;
 
   i = 2000;
-  
+
   while( i-- )
     {
     set.set( "this is, just a simple. but fixed, nonsense test, voila :)" );
     cat.cat( "this is, just a simple. but fixed, nonsense test, voila :)" );
     setn.setn( "this is, just a simple. but fixed, nonsense test, voila :)", 20 );
     catn.catn( "this is, just a simple. but fixed, nonsense test, voila :)", 20 );
-    
+
     sete = "this is, just a simple. but fixed, nonsense test, voila :)";
     setp += "this is, just a simple. but fixed, nonsense test, voila :)";
     }
@@ -208,7 +223,7 @@ void test4()
   printf( "setp = %d\n", str_len( setp ) );
 
   printf( "--------------------\n" );
-  
+
   i = 2000;
   while( i-- )
     {
@@ -220,7 +235,7 @@ void test4()
     }
   printf( "set  = %s\n", set.data() );
   printf( "setn = %s\n", setn.data() );
-  
+
   printf( "---array sort-------\n" );
   va.undef();
   va = str_split( "[, \t]+", "this is, just a simple. but fixed, nonsense test, voila :)" );
@@ -230,19 +245,19 @@ void test4()
   va.sort( 1 );
   va.print();
   printf( "--------------------\n" );
-  
+
 }
 
 void test5()
 {
   VTrie tr; // hash-like
   VArray va;
-  
+
   // inserting keys and values
   tr[ "key1" ] = "data1";
   tr[ "key2" ] = "data2";
   tr[ "key3" ] = "data3";
-  
+
   tr.print();
   tr.reverse();
   tr.print();
@@ -250,7 +265,7 @@ void test5()
   tr.print();
 
   VCharSet cs;
-  
+
   cs.push( 'a' );
   printf( "char_set: %d, %d\n", cs.in( 'a' ), cs.in( 'z' ) );
   cs.undef( 'a' );
@@ -262,9 +277,9 @@ void test5()
     {
     cs.push( i );
     }
-  cs.undef();  
+  cs.undef();
+
 
-  
   printf( "************************ test 5 ends here\n" );
 }
 
@@ -272,7 +287,7 @@ void test6()
 {
   VRegexp re;
   VArray va;
-  
+
   re.comp( "^([^!]+)!(.+)=apquxz(.+)$" );
   int i = re.m( "abc!pqr=apquxz.ixr.zzz.ac.uk" );
   i--;
@@ -282,7 +297,7 @@ void test6()
     i--;
     }
   va.print();
-  
+
   va.undef();
   va += "/this/is/samle/file.tail";
   va += "/file.tail";
@@ -290,9 +305,9 @@ void test6()
   va += "/this/..../is/../samle/.file.tail";
   va += "/.file.tail";
   va += "/";
-  
+
   const char* ps;
-  
+
   va.reset();
   while( ( ps = va.next() ) )
     {
@@ -305,9 +320,9 @@ void test6()
     printf( "reduced path is: %s\n", (const char*)str_reduce_path( ps ) );
     printf( "dot reduce sample is: %s\n", (const char*)str_dot_reduce( ps, 10 ) );
     }
-    
-  va.fsave( "/tmp/a.aaa" );  
-  va.fload( "/tmp/a.aaa" );  
+
+  va.fsave( "/tmp/a.aaa" );
+  va.fload( "/tmp/a.aaa" );
   va.print();
 }
 
@@ -316,12 +331,12 @@ void test7()
   VTrie tr; // hash-like
   VTrie tr2; // hash-like
   VArray va;
-  
+
   // inserting keys and values
   tr[ "key1" ] = "data1";
   tr[ "key2" ] = "data2";
   tr[ "key3" ] = "data3";
-  
+
   tr.print();
   printf( "---------------------------------1---\n" );
   tr.reverse();
@@ -330,15 +345,15 @@ void test7()
   tr.reverse();
   tr.print();
   printf( "---------------------------------3---\n" );
-  
+
   tr2 = str_split( " ", "this is simple one way test" );
   tr2.print();
   printf( "---------------------------------4---\n" );
-  
+
   tr2 += tr;
   tr2.print();
   printf( "---------------------------------5---\n" );
-  
+
   va = tr2;
   va.print();
   printf( "---------------------------------6---\n" );
@@ -348,43 +363,43 @@ void test8()
 {
   VString v1;
   VString v2;
-  
+
   v1 = "this is simple test ";
   v1 *= 1024;
-  
+
   printf( "v1 len: %d\n", str_len( v1 ) );
-  
+
   v2.compact( 1 ); // makes v2 compact, i.e. it will get as much memory as it
                    // needs. otherwise it will get fixed amount of blocks
-  
+
   v2 = v1; // data is shared between v1 and v2. any change to v1 or v2 will
            // detach this data and both will get own copy
-  
+
   v2[0] = ' '; // this will create own data for v2
-  
+
   str_tr( v2, "ti", "TI" ); // capitalize T and I
-  
+
   v2 = ""; // this will free all data allocated by v2
-  
+
   printf( "copy 7,6: [%s]", (const char*)str_copy( v2, v1, 8, 6 ) );
   printf( "copy 10: [%s]", (const char*)str_copy( v2, v1, -10 ) );
-  
+
   printf( "************************ test 5 ends here\n" );
 }
 
 int main( int argc, char* argv[] )
 {
   //#define PAT "9892009"
-  
-  
+
+
   #define PAT "MARINOW Uliqn P. prof. dtn kw.Wladaq ul.Witoshki granit 11"
   //#define PAT "marinow uliqn p. prof. dtn kw.wladaq ul.witoshki granit 11"
   printf( "found at pos %ld\n", file_pattern_search( PAT, strlen(PAT),
                                "/tmp/ss.txt", "",
                                mem_quick_search ) );
-  
+
   //printf( "expand=[%s]\n", (const char*)tilde_expand( "~root/" ) );
-  
+
   /**/
   test1();
   test2();
