@@ -1,15 +1,17 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-1999
+ * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-2003
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
+ * $Id: unicon.h,v 1.4 2003/01/21 19:56:35 cade Exp $
+ *
  */
 
 #ifndef _UNICON_H_
 #define _UNICON_H_
 
-#include <target.h>
+#include "target.h"
 
 #ifdef _TARGET_UNKNOWN_
   #error "I don't know what is the target platform"
